searchData={"items":[{"type":"module","title":"MishkaInstaller","doc":"# Mishka Installer is a system plugin(event) manager and run time installer for Elixir.\n\n[![MishkaInstaller CI](https://github.com/mishka-group/mishka_installer/actions/workflows/ci.yml/badge.svg)](https://github.com/mishka-group/mishka_installer/actions/workflows/ci.yml) [![Hex.pm](https://img.shields.io/badge/hex-0.1.0-blue.svg)](https://hex.pm/packages/mishka_installer) [![GitHub license](https://img.shields.io/badge/apache-2.0-green.svg)](https://raw.githubusercontent.com/mishka-group/mishka_installer/master/LICENSE) ![GitHub issues](https://img.shields.io/github/issues/mishka-group/mishka_installer)","ref":"MishkaInstaller.html"},{"type":"module","title":"Build purpose - MishkaInstaller","doc":"---\n\nImagine you are going to make an application that will have many plugins built for it in the future.\nBut the fact that many manipulations will be made on your source code makes it difficult to\nmaintain the application. For example, you present a content management system for your users,\nand now they need to activate a section for registration and `SMS`; the system allows you to\npresent your desired input/output absolutely plugin oriented to your users and makes it\npossible for the developers to write their required applications beyond the core source code.\n\n\n> **NOTICE**: Do not use the master branch; this library is under heavy development.\n> Expect version 0.1.0, and for using the new features, please wait until a new release is out.\n\n\n##### This library is divided into the following main sections:\n\n- [Events and Hook](#events-and-hook)\n- [Plugin management system theory and installation of Elixir libraries at runtime](#plugin-management-system-theory-and-installation-of-elixir-libraries-at-runtime)","ref":"MishkaInstaller.html#module-build-purpose"},{"type":"module","title":"Events and Hook - MishkaInstaller","doc":"---\n\nIn this section, you can define a series of events for each event,\nfor example: after **successful registration** or **unsuccessful purchase** from “the store”,\nand for each event, put a set of callbacks in one module.\n\nAfter completing this step, when the user wants to create his own plugin,\nthe Macro `behaviour` and `Hook` module will call you in its action module.\n\nThis helps you have a regular and `error-free` system, and the library uses an almost\nintegrated structure in all of its events.\n\n> In **Mishka Installer** Library, a series of action or hook functions are\ngiven to the developer of the main plugin or software, which helps build plugins **outside**/**inside**\nthe system and convert software sections into separate events.\n\n**Some of the functions of this module include the following:**\n\n- Retrieves the merged configuration for the hook module.\n- Register a plugin for a specific event.\n- Start a plugin of a specific event.\n- Restart a plugin of a specific event.\n- Stop a plugin of a specific event.\n- Unregister a plugin of a specific event.\n- Retrieves a Plugin `GenServer` state.\n- Each plugin has A `GenServer` to do some auto jobs.\n\n> For more information please see the `MishkaInstaller.Event.Hook` module.\n\n##### Example:\n\n```elixir\ndefmodule RegisterEmailSender do\n  use MishkaInstaller.Event.Hook, event: \"after_success_login\"\n\n  def call(entries) do\n    {:reply, entries}\n  end\nend\n```\n\n**If you want to change a series of default information, do this:**\n\n```elixir\nuse MishkaInstaller.Event.Hook,\n  event: \"after_success_login\",\n  initial: %{depends: [SomeEvent], priority: 20}\n```\n\n**You can call all plugins of an event:**\n\n```elixir\nalias MishkaInstaller.Event.Hook\n\n# Normal call an event plugins\nHook.call(\"after_success_login\", params)\n\n# If you want certain entries not to change\nHook.call(\"after_success_login\", params, [private: something_based_on_your_data])\n\n# If you want the initial entry to be displayed at the end\nHook.call(\"after_success_login\", params, [return: true])\n```\n\n**Note: If you want your plugin to execute automatically,\nall you need to do is send the name of the module in which you utilized\nthe `MishkaInstaller.Event.Hook` to the Application module.***\n\n```elixir\nchildren = [\n  ...\n  RegisterEmailSender\n]\n\n...\nopts = [strategy: :one_for_one, name: SomeModule.Supervisor]\nSupervisor.start_link(children, opts)\n```\n\n> This module is a read-only in-memory storage optimized for the fastest possible read times\n> not for write strategies.","ref":"MishkaInstaller.html#module-events-and-hook"},{"type":"module","title":"Plugin management system theory and installation of Elixir libraries at runtime - MishkaInstaller","doc":"---\n\nThe functionality of this library can be conceptualized as an architectural potential that is\ncomposed of two primary components, which are as follows:\n\n1. Event management (Plugin Hook powered by **Elixir Macro**)\n2. Managing removal and installation of Elixir libraries at `runtime`.\n\nWhen a programmer uses this library for his own software development, we sought to\nensure that in addition to the established capabilities, he also has access to a set of\nappropriate standards for software development that are based on preset behaviors that can be applied;\nThis was our goal.\n\nIt streamlines and organizes the work of a group working on a project while also facilitating\nthe creation of software.\nError control and tree structure, which enable us to develop a system that is robust and trustworthy,\nare two of the guiding ideas behind the construction of this library, which has garnered\nattention from people all around the world.\n\nThe [MishkaInstaller](https://github.com/mishka-group/mishka_installer) library can be created in\nvarious systems, and it provides fundamental capabilities such as the management of plugin states\nand the application of standard behaviors.\nThese features can all be accessed by specified hooks in the library.\n\n> **The installer is in beta mode, use it carefully and some of its functionality\n> may not work in the Elixir `release`.**\n\n\n##### Example:\n\n```elixir\nalias MishkaInstaller.Installer.Installer\n\n# Normal calling\nInstaller.install(%__MODULE__{app: \"some_name\", path: \"some_name\", type: :hex})\n\n# Normal calling\nInstaller.uninstall(%__MODULE__{app: \"some_name\", path: \"some_name\", type: :hex})\n\n# Normal calling\nInstaller.async_install(%__MODULE__{app: \"some_name\", path: \"some_name\", type: :hex})\n```\n\n> For more information please see the `MishkaInstaller.Installer.Installer` module.","ref":"MishkaInstaller.html#module-plugin-management-system-theory-and-installation-of-elixir-libraries-at-runtime"},{"type":"module","title":"Installing the library: - MishkaInstaller","doc":"---\n\nIt should be noted that this library must be installed in two parts of the plugin and the\nsoftware that wants to display the plugins, and due to its small dependencies, it does\nnot cause any problems. To install, just add this library to your \"mix.exs\" in the \"deps\"\nfunction as follows:\n\n```elixir\ndef deps do\n  [\n    {:mishka_installer, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThe docs can be found at https://hexdocs.pm/mishka_installer.\n\n---\n\n# Donate\n\nIf the project was useful for you, the only way you can donate to me is the following ways\n\n| **BTC**                                                                                                                            | **ETH**                                                                                                                            | **DOGE**                                                                                                                           | **TRX**                                                                                                                            |\n| ---------------------------------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------- |\n|   |   |   |   |\n\n \n   Donate addresses \n\n**BTC**:‌\n\n```\nbc1q24pmrpn8v9dddgpg3vw9nld6hl9n5dkw5zkf2c\n```\n\n**ETH**:\n\n```\n0xD99feB9db83245dE8B9D23052aa8e62feedE764D\n```\n\n**DOGE**:\n\n```\nDGGT5PfoQsbz3H77sdJ1msfqzfV63Q3nyH\n```\n\n**TRX**:\n\n```\nTBamHas3wAxSEvtBcWKuT3zphckZo88puz\n```","ref":"MishkaInstaller.html#module-installing-the-library"},{"type":"function","title":"MishkaInstaller.__information__/0","doc":"Helper function to specify project path and return the current Mix environment.\n\n```elixir\nMishkaInstaller.__information__()\n```\n\n#### Please before using this library set these:\n\n- Set `PROJECT_PATH` as the **System env** or `:mishka, :project_path` as the **Application env**\n- Set `MIX_ENV` as the **System env** or `:mishka, :project_env` as the **Application env**","ref":"MishkaInstaller.html#__information__/0"},{"type":"module","title":"MishkaInstaller.Event.Event","doc":"The `MishkaInstaller.Event.Event` module is the core of events, which comprises pre-prepared\nstrategies for the implementation and management of plugins introduced to the system\naround various events.\nThese implementation and management strategies are included in the Event module.\n\n> #### Use cases information {: .tip}\n>\n> The fundamental criteria of the same system serve as the basis for the specification of\n> these strategies, which are aimed at common systems.\n> Therefore, you are not permitted to utilize this module if you believe that\n> your technique is different.\n\nIn addition, it is important to remember that the other part of this module is\nconnected to the queries that are required to be made to the **Erlang runtime database**,\nwhich is known as `Mnesia`.\n\nUsing this functionality, you will be able to store the information that is\nassociated with each plugin in it.\n\n> Note that all storages are based on the name of an event. See `MishkaInstaller.Event.Hook` module.\n\n---\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n>\n> This module is a read-only in-memory storage optimized for the fastest possible read times\n> not for write strategies.","ref":"MishkaInstaller.Event.Event.html"},{"type":"module","title":"Note: - MishkaInstaller.Event.Event","doc":"When you are writing, you should always make an effort to be more careful because\nyou might get reconditioned during times of high traffic.\nWhen it comes to reading and running all plugins, this problem only occurs when a\nmodule is being created and destroyed during the compilation process.","ref":"MishkaInstaller.Event.Event.html#module-note"},{"type":"function","title":"MishkaInstaller.Event.Event.builder/2","doc":"","ref":"MishkaInstaller.Event.Event.html#builder/2"},{"type":"function","title":"MishkaInstaller.Event.Event.delete/2","doc":"To delete a plugin from Mnesia database by id or name.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Event.Event.html#delete/2"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.delete/2","doc":"```elixir\ndelete(:name, TestApp.User.Auth)\n\ndelete(:id, \"c63aea42-209a-40fb-b5c6-a0d28ee7e25b\")\n```","ref":"MishkaInstaller.Event.Event.html#delete/2-example"},{"type":"function","title":"MishkaInstaller.Event.Event.drop/0","doc":"To drop all plugins from Mnesia database.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Event.Event.html#drop/0"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.drop/0","doc":"```elixir\ndrop()\n```","ref":"MishkaInstaller.Event.Event.html#drop/0-example"},{"type":"function","title":"MishkaInstaller.Event.Event.enforce_keys/0","doc":"","ref":"MishkaInstaller.Event.Event.html#enforce_keys/0"},{"type":"function","title":"MishkaInstaller.Event.Event.enforce_keys/1","doc":"","ref":"MishkaInstaller.Event.Event.html#enforce_keys/1"},{"type":"function","title":"MishkaInstaller.Event.Event.get/0","doc":"To get all plugins information from Mnesia database.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Event.Event.html#get/0"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.get/0","doc":"```elixir\nget()\n```","ref":"MishkaInstaller.Event.Event.html#get/0-example"},{"type":"function","title":"MishkaInstaller.Event.Event.get/1","doc":"To get a plugin information from Mnesia database by id.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Event.Event.html#get/1"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.get/1","doc":"```elixir\nget(\"c63aea42-209a-40fb-b5c6-a0d28ee7e25b\")\n```","ref":"MishkaInstaller.Event.Event.html#get/1-example"},{"type":"function","title":"MishkaInstaller.Event.Event.get/2","doc":"To get all plugins or one plugin information from Mnesia database.\n\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Event.Event.html#get/2"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.get/2","doc":"```elixir\n# All plugins of an event\nget(:event, \"after_login\")\n\n# All plugins of an extension\nget(:extension, :mishka_developer_tools)\n\n# Get a plugin\nget(:name, TestApp.User.Auth)\n```","ref":"MishkaInstaller.Event.Event.html#get/2-example"},{"type":"function","title":"MishkaInstaller.Event.Event.group_events/1","doc":"To get all the events defined in the Mnesia database (Only unique items are returned).\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Event.Event.html#group_events/1"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.group_events/1","doc":"```elixir\ngroup_events()\n```","ref":"MishkaInstaller.Event.Event.html#group_events/1-example"},{"type":"function","title":"MishkaInstaller.Event.Event.ids/0","doc":"To get all plugins ids from Mnesia database.\n\n\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Event.Event.html#ids/0"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.ids/0","doc":"```elixir\nids()\n```","ref":"MishkaInstaller.Event.Event.html#ids/0-example"},{"type":"function","title":"MishkaInstaller.Event.Event.keys/0","doc":"","ref":"MishkaInstaller.Event.Event.html#keys/0"},{"type":"function","title":"MishkaInstaller.Event.Event.keys/1","doc":"","ref":"MishkaInstaller.Event.Event.html#keys/1"},{"type":"function","title":"MishkaInstaller.Event.Event.register/3","doc":"If you want to store a plugin for a particular event, this function is a predefined strategy\nthat you can use. Additionally, it performs a check on the integrity of the plugin module and\ngathers other information that is necessary while it is being stored in `Mnesia`.\n\nInputs for this function include the **name of the plugin**, **the name of the event**, and some\n**fundamental information**.\nChecking the `struct` of this module is one way to add the `initial event` to the modules.\n\nSee: `%MishkaInstaller.Event.Event{}`\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n>\n> This module is a read-only in-memory storage optimized for the fastest possible read times\n> not for write strategies.\n>\n> It is not appropriate for the user to have any direct influence on this function because\n> it is intended for the use of the programmer. It should be brought to your attention that\n> this particular function, which incorporates the `Write` activity, should often be utilized\n> only once at the beginning of the project.","ref":"MishkaInstaller.Event.Event.html#register/3"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.register/3","doc":"```elixir\nregister(TestApp.User.Auth, \"after_login\", %{priority: 2})\n```\n\n> This function is only responsible for registering the plugin; it does not carry\n> out any activities related to execution. Please refer to function `start/2` in order to execute","ref":"MishkaInstaller.Event.Event.html#register/3-example"},{"type":"function","title":"MishkaInstaller.Event.Event.restart/1","doc":"This function restarts all events, For more information please see `restart/2`.","ref":"MishkaInstaller.Event.Event.html#restart/1"},{"type":"function","title":"MishkaInstaller.Event.Event.restart/3","doc":"A pre-made strategy for restarting a plugin is what this method is clearly named.\nKeep in mind that you'll need to register and start this plugin ahead of time.\n\nThe requested Event will be compiled once more in the event that the\nplugin is able to restart properly. **This is a heavy write activity**\n\n\n> #### Use cases information {: .tip}\n>\n> The `start/2` function and this idea are often mistaken. Actually, this function does\n> the same operations as the start function, but it re-examines the conditions.\n> You can tailor your own function to meet the specific needs of your system, and there's\n> already a plan in place. The `MishkaInstaller.Event.Hook` module decides on this potential.\n\n\n---\n\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n>\n> This module is a read-only in-memory storage optimized for the fastest possible read times\n> not for write strategies.\n>\n> It is not appropriate for the user to have any direct influence on this function because\n> it is intended for the use of the programmer. It should be brought to your attention that\n> this particular function, which incorporates the `Write` activity, should often be utilized\n> only once at the beginning of the project.\n\n##### Compile path: `MishkaInstaller.Event.ModuleStateCompiler.State.YourEvent`.","ref":"MishkaInstaller.Event.Event.html#restart/3"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.restart/3","doc":"```elixir\n# Restart a plugin\nrestart(:name, TestApp.User.Auth)\n\n# Restart all plugins of an event\nrestart(:event, \"after_login\")\n```","ref":"MishkaInstaller.Event.Event.html#restart/3-example"},{"type":"function","title":"MishkaInstaller.Event.Event.start/1","doc":"This function starts all events, For more information please see `start/2`.","ref":"MishkaInstaller.Event.Event.html#start/1"},{"type":"function","title":"MishkaInstaller.Event.Event.start/3","doc":"A pre-made strategy for starting a plugin is what this method is clearly named.\nKeep in mind that you'll need to register this plugin ahead of time.\n\nThe requested Event will be compiled once more in the event that the\nplugin is able to start properly. **This is a heavy write activity**\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n>\n> This module is a read-only in-memory storage optimized for the fastest possible read times\n> not for write strategies.\n>\n> It is not appropriate for the user to have any direct influence on this function because\n> it is intended for the use of the programmer. It should be brought to your attention that\n> this particular function, which incorporates the `Write` activity, should often be utilized\n> only once at the beginning of the project.\n\n##### Compile path: `MishkaInstaller.Event.ModuleStateCompiler.State.YourEvent`.","ref":"MishkaInstaller.Event.Event.html#start/3"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.start/3","doc":"```elixir\n# Start a plugin\nstart(:name, TestApp.User.Auth)\n\n# Start all plugins of an event\nstart(:event, \"after_login\")\n```","ref":"MishkaInstaller.Event.Event.html#start/3-example"},{"type":"function","title":"MishkaInstaller.Event.Event.stop/1","doc":"This function stops all events, For more information please see `stop/2`.","ref":"MishkaInstaller.Event.Event.html#stop/1"},{"type":"function","title":"MishkaInstaller.Event.Event.stop/3","doc":"A pre-made strategy for stopping a plugin is what this method is clearly named.\nKeep in mind that you'll need to register and start this plugin ahead of time.\n\nThe requested Event will be compiled once more in the event that the\nplugin is able to stop properly. **This is a heavy write activity**\n\n> #### Use cases information {: .tip}\n>\n> Keep in mind that the only thing that happens when you stop a plugin is that its database status\n> changes to `stopped` and it is removed from the list of compiled modules\n> of the event in question. However, its modules, notably `GenServer`,\n> will still be operational and will not be entirely removed from the system.\n\n---\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n>\n> This module is a read-only in-memory storage optimized for the fastest possible read times\n> not for write strategies.\n>\n> It is not appropriate for the user to have any direct influence on this function because\n> it is intended for the use of the programmer. It should be brought to your attention that\n> this particular function, which incorporates the `Write` activity, should often be utilized\n> only once at the beginning of the project.","ref":"MishkaInstaller.Event.Event.html#stop/3"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.stop/3","doc":"```elixir\n# Stop a plugin\nstop(:name, TestApp.User.Auth)\n\n# Stop all plugins of an event\nstop(:event, \"after_login\")\n```","ref":"MishkaInstaller.Event.Event.html#stop/3-example"},{"type":"function","title":"MishkaInstaller.Event.Event.unique/2","doc":"To check is a plugin unique or not in Mnesia database.\n\n> It returns `:ok`, or `{:error, reason}`. Note that if the requested plugin does not exist,\n> it means it is unique, and if it is already in the database, it means it is not unique\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Event.Event.html#unique/2"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.unique/2","doc":"```elixir\nunique(:name, TestApp.User.Auth)\n```","ref":"MishkaInstaller.Event.Event.html#unique/2-example"},{"type":"function","title":"MishkaInstaller.Event.Event.unique?/2","doc":"This function is exactly like `unique/2` function, except that its output is a Boolean.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Event.Event.html#unique?/2"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.unique?/2","doc":"```elixir\nunique?(:name, TestApp.User.Auth)\n```","ref":"MishkaInstaller.Event.Event.html#unique?/2-example"},{"type":"function","title":"MishkaInstaller.Event.Event.unregister/1","doc":"This function stops all unregisters, For more information please see `unregister/2`.","ref":"MishkaInstaller.Event.Event.html#unregister/1"},{"type":"function","title":"MishkaInstaller.Event.Event.unregister/3","doc":"This function removes the plugin from the database and **kills** all processes associated to it,\nin addition to doing the exact same thing as the `stop/2` function.\n\n\nThe requested Event will be compiled once more in the event that the\nplugin is able to unregister properly. **This is a heavy write activity**\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n>\n> This module is a read-only in-memory storage optimized for the fastest possible read times\n> not for write strategies.\n>\n> It is not appropriate for the user to have any direct influence on this function because\n> it is intended for the use of the programmer. It should be brought to your attention that\n> this particular function, which incorporates the `Write` activity, should often be utilized\n> only once at the beginning of the project.","ref":"MishkaInstaller.Event.Event.html#unregister/3"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.unregister/3","doc":"```elixir\n# Unregister a plugin\nunregister(:name, TestApp.User.Auth)\n\n# Unregister all plugins of an event\nunregister(:event, \"after_login\")\n```","ref":"MishkaInstaller.Event.Event.html#unregister/3-example"},{"type":"function","title":"MishkaInstaller.Event.Event.write/1","doc":"To Add or edit a plugin information from Mnesia database.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Event.Event.html#write/1"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.write/1","doc":"```elixir\nwrite(%MishkaInstaller.Event.Event{name: TestApp.User.Auth, event: \"after_login\", extension: :test_app})\n```","ref":"MishkaInstaller.Event.Event.html#write/1-example"},{"type":"function","title":"MishkaInstaller.Event.Event.write/3","doc":"To edit a specific field/fields of a plugin from the Mnesia database.\n\n> The first input can only be name and ID `[:id, :name]`.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Event.Event.html#write/3"},{"type":"function","title":"Example: - MishkaInstaller.Event.Event.write/3","doc":"```elixir\nwrite(:name, TestApp.User.Auth, %{status: :started})\n```","ref":"MishkaInstaller.Event.Event.html#write/3-example"},{"type":"type","title":"MishkaInstaller.Event.Event.builder_entry/0","doc":"","ref":"MishkaInstaller.Event.Event.html#t:builder_entry/0"},{"type":"type","title":"MishkaInstaller.Event.Event.error_return/0","doc":"","ref":"MishkaInstaller.Event.Event.html#t:error_return/0"},{"type":"type","title":"MishkaInstaller.Event.Event.okey_return/0","doc":"","ref":"MishkaInstaller.Event.Event.html#t:okey_return/0"},{"type":"type","title":"MishkaInstaller.Event.Event.status/0","doc":"","ref":"MishkaInstaller.Event.Event.html#t:status/0"},{"type":"type","title":"MishkaInstaller.Event.Event.t/0","doc":"","ref":"MishkaInstaller.Event.Event.html#t:t/0"},{"type":"module","title":"MishkaInstaller.Event.Hook","doc":"The `MishkaInstaller.Event.Hook` module provides a set of functionalities to manage event hooks\nwithin the Mishka Installer system.\n\nIt leverages `GenServer` to handle asynchronous event-driven operations and offers a set of\nmacros and functions for registering, starting, stopping, and managing hooks dynamically.\n\nIn addition to being one of the most significant modules of the MishkaInstaller library,\nthe Hook module gives you the ability to make the library as a whole,\nas well as the projects that make use of this library, more modular.\n\nIt is essential to comprehend that you may treat any action performed independently\nas an event and register an unlimited number of plugins for that event.\n\nYou can do this by considering that action to be done separately.\nEach plugin has the potential to have its own individual inputs and outputs,\nand depending on the architecture of the area that you want to use Hook in,\nyou may even be able to change the output and send it to other plugins.\n\nThroughout all of the many parts that have been built for this module,\nit has been attempted to have a flexible approach to dealing with errors\nand to provide the programmer with a wide variety of options.\n\nWith the additional functions at her disposal, the programmer can actually create a\ngateway in their projects, where the data flow must pass through several gates,\nwhether it changes or remains unchanged, and a series of operations are performed.\n\nFor illustration's sake, let's suppose you want the registration system to allow users\nto sign up for social networks on Twitter and Google.\n\nWhen you use this library, it is conceivable that you can quickly display HTML\nor even operate in the background before registering after registering.\n\nThis is a significant improvement over the standard practice,\nin which you are required to modify the primary codes of your project. Create a separate plugin.\n\nIt is interesting to notice that these facilities are quite basic and convenient for the admin user.\n\nIf this opportunity is provided, the management can manage its own plugins in different ways\nif it has a dashboard.\n\nIt is crucial to highlight that each plugin is its own `GenServer`; in addition,\nit is dynamically supervised, and the information is stored in the database as well as in Mnesia.\n\nFurthermore, this section is very useful even if the programmer wants to perform many tasks\nthat are not associated with Perform defined functions.\n\nThe fact that the programmers have to introduce each plugin to the system based on a specific\nbehavior is one of the exciting aspects of using this section. Additionally,\nthe system has prepared some default behaviors to force the programmers\nto introduce the plugins in the order specified by the system.\n\nThe use of custom behaviors on the part of the programmer and MishkaInstaller itself makes debugging easier;\nhowever, this library does not leave the programmer to fend for themselves in this significant matter;\nrather, a straightforward error storage system is prepared based on the particular activities being performed.\n\nShould prevent any unpredictable behavior at any costs.\n\n---","ref":"MishkaInstaller.Event.Hook.html"},{"type":"module","title":"Build purpose - MishkaInstaller.Event.Hook","doc":"---\n\nImagine you are going to make an application that will have many plugins built for it in the future.\nBut the fact that many manipulations will be made on your source code makes it\ndifficult to maintain the application.\n\nFor example, you present a content management system for your users, and now they need to\nactivate a section for registration and SMS; the system allows you to present your desired\n`input/output` absolutely plugin oriented to your users and makes it possible for the\ndevelopers to write their required applications beyond the core source code.\n\n---\n\nThe library categorizes your whole software design structure into many parts;\nand has an appropriate dependency that is optional with `GenServer`;\nit considers a monitoring branch for each of your plugins, which results in fewer errors and `downtime`.\n\nThe considered part:\n\n1. Behaviors and events\n2. Recalling or `Hook` with priority\n3. `State` management and links to the database (`Mnesia` support)\n\n> Most of the sections mentioned can be fully customized to suit your needs.\n> This library offers a range of predefined strategies for public use, which might\n> be sufficient for your requirements.\n\nIn Mishka Elixir Plugin Management Library, a series of action or `hook` functions are given\nto the developer of the main plugin or software, which helps build plugins outside the system\nand convert software sections into separate `events`.\n\nSome of the functions of this module include the following:\n\n- `config/0` - Retrieves the merged configuration for the hook module.\n- `config/1` - Retrieves a specific configuration value by key.\n- `register/0` - Register a plugin for a specific event.\n- `start/0` - Start a plugin of a specific event.\n- `restart/0` - Restart a plugin of a specific event.\n- `stop/0` - Stop a plugin of a specific event.\n- `unregister/0` - Unregister a plugin of a specific event.\n- `get/0` - Retrieves a Plugin `GenServer` state.","ref":"MishkaInstaller.Event.Hook.html#module-build-purpose"},{"type":"module","title":"Example: - MishkaInstaller.Event.Hook","doc":"```elixir\ndefmodule RegisterEmailSender do\n  use MishkaInstaller.Event.Hook, event: \"after_success_login\"\n\n  def call(entries) do\n    {:reply, entries}\n  end\nend\n```\n\nIf you want to change a series of default information, do this:\n\n```elixir\nuse MishkaInstaller.Event.Hook,\n  event: \"after_success_login\",\n  initial: %{depends: [SomeEvent], priority: 20}\n```\n\n> There should be one main functions in each plugin, namely `call`. In this function,\n> whenever the action function calls this special event for which the plugin is written,\n> based on priority. This plugin is also called. But what is important is the final output\n> of the `call` function.\n> This output may be the input of other plugins with higher priorities.\n> The order of the plugins is from small to large, and if several plugins are registered for a number,\n> it is sorted by name in the second parameter. And it should be noted that in any case,\n> if you did not want this `state` to go to other plugins and the last output is returned in the same plugin,\n> and you can replace `{:reply, :halt, new_state}` with `{:reply, new_state}`.\n\n\n**Note: If you want your plugin to execute automatically,\nall you need to do is send the name of the module in which you utilized\nthe `MishkaInstaller.Event.Hook` to the Application module.***\n\n```elixir\nchildren = [\n  ...\n  RegisterEmailSender\n]\n\n...\nopts = [strategy: :one_for_one, name: SomeModule.Supervisor]\nSupervisor.start_link(children, opts)\n```\n\n#### You can call all plugins of an event:\n\n```elixir\nalias MishkaInstaller.Event.Hook\n\n# Normal call an event plugins\nHook.call(\"after_success_login\", params)\n\n# If you want certain entries not to change\nHook.call(\"after_success_login\", params, [private: something_based_on_your_data])\n\n# If you want the initial entry to be displayed at the end\nHook.call(\"after_success_login\", params, [return: true])\n```\n\n> #### Use cases information {: .tip}\n>\n> Module `MishkaInstaller.Event.Event` has all of the preset functionalities, and it is\n> simple for you to build and implement your own strategy because of this.\n>\n> You can override these functions:\n> `register: 0`, `start: 0`, `restart: 0`, `stop: 0`, `unregister: 0`, `get: 0`","ref":"MishkaInstaller.Event.Hook.html#module-example"},{"type":"function","title":"MishkaInstaller.Event.Hook.call/3","doc":"Invokes the `call/2` function of the specified event module.","ref":"MishkaInstaller.Event.Hook.html#call/3"},{"type":"function","title":"Parameters - MishkaInstaller.Event.Hook.call/3","doc":"- `event` (String.t()): The name of the event.\n- `data` (any()): The data to be passed to the event module.\n- `args` (keyword()): Additional arguments for the call (`private`, `return`).","ref":"MishkaInstaller.Event.Hook.html#call/3-parameters"},{"type":"function","title":"Returns - MishkaInstaller.Event.Hook.call/3","doc":"- `any()`: The result of the event module's `call/2` function.","ref":"MishkaInstaller.Event.Hook.html#call/3-returns"},{"type":"function","title":"Examples - MishkaInstaller.Event.Hook.call/3","doc":"```elixir\nMishkaInstaller.Event.Hook.call(\"my_event\", %{}, [])\n```","ref":"MishkaInstaller.Event.Hook.html#call/3-examples"},{"type":"function","title":"MishkaInstaller.Event.Hook.call!/3","doc":"The only difference between this function and the `call/3` function is that the former\ndoes not check in a single step whether the required event has been compiled or not.\nWhen you are 100% certain that the event you want is present in the system,\nusing it is the best option.","ref":"MishkaInstaller.Event.Hook.html#call!/3"},{"type":"module","title":"MishkaInstaller.Event.ModuleStateCompiler","doc":"`The MishkaInstaller.Event.ModuleStateCompiler` module is designed to dynamically create and manage\nevent-driven modules that handle state and plugins within the Mishka Installer system.\nThis module provides functions to create, purge, and verify the initialization state of these event modules.\n\n**In fact, this system creates a runtime module for each event based on system\nrequirements and conditions in the `MishkaInstaller.Event.Event` and `MishkaInstaller.Event.Hook` modules,\nwhich also contains a series of essential functions.**\n\n---\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n>\n> This module is a read-only in-memory storage optimized for the fastest possible read times\n> not for write strategies.\n\n##### Compile path: `MishkaInstaller.Event.ModuleStateCompiler.State.YourEvent`.","ref":"MishkaInstaller.Event.ModuleStateCompiler.html"},{"type":"module","title":"Note: - MishkaInstaller.Event.ModuleStateCompiler","doc":"When you are writing, you should always make an effort to be more careful because\nyou might get reconditioned during times of high traffic.\nWhen it comes to reading and running all plugins, this problem only occurs when a\nmodule is being created and destroyed during the compilation process.","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#module-note"},{"type":"function","title":"MishkaInstaller.Event.ModuleStateCompiler.compile_initialize?/1","doc":"Checks if the event module is compiled and loaded.\n\n> Just should be used when you need one time or in compile time","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#compile_initialize?/1"},{"type":"function","title":"Examples - MishkaInstaller.Event.ModuleStateCompiler.compile_initialize?/1","doc":"```elixir\ncompile_initialize?(\"event_name\")\n```","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#compile_initialize?/1-examples"},{"type":"function","title":"MishkaInstaller.Event.ModuleStateCompiler.create/2","doc":"Creates a new module based on the provided event name and plugins.","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#create/2"},{"type":"function","title":"Parameters - MishkaInstaller.Event.ModuleStateCompiler.create/2","doc":"- `plugins` (list): A list of plugin(`ishkaInstaller.Event.Event`) structs to be included in the\nnew module.\n- `event` (String.t()): The name of the event for which the module is created.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measure","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#create/2-parameters"},{"type":"function","title":"Examples - MishkaInstaller.Event.ModuleStateCompiler.create/2","doc":"```elixir\nalias MishkaInstaller.Event.Event\ncreate([%Event{name: MyPlugin}], \"event_name\")\n```","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#create/2-examples"},{"type":"function","title":"MishkaInstaller.Event.ModuleStateCompiler.initialize?/1","doc":"Checks if the event module is initialized.","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#initialize?/1"},{"type":"function","title":"Examples - MishkaInstaller.Event.ModuleStateCompiler.initialize?/1","doc":"```elixir\ninitialize?(\"event_name\")\n```","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#initialize?/1-examples"},{"type":"function","title":"MishkaInstaller.Event.ModuleStateCompiler.module_event_name/1","doc":"Generates a module name based on the event name.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measure","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#module_event_name/1"},{"type":"function","title":"Examples - MishkaInstaller.Event.ModuleStateCompiler.module_event_name/1","doc":"```elixir\nmodule_event_name(\"event_name\")\n```","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#module_event_name/1-examples"},{"type":"function","title":"MishkaInstaller.Event.ModuleStateCompiler.purge/1","doc":"Purges the specified event modules or a module.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measure","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#purge/1"},{"type":"function","title":"Examples - MishkaInstaller.Event.ModuleStateCompiler.purge/1","doc":"```elixir\npurge(\"event_name\")\n```","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#purge/1-examples"},{"type":"function","title":"MishkaInstaller.Event.ModuleStateCompiler.purge_create/2","doc":"Purges (`purge/1`) an existing module and creates a new one (`create/2`) with the provided plugins and event name.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measure","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#purge_create/2"},{"type":"function","title":"Examples - MishkaInstaller.Event.ModuleStateCompiler.purge_create/2","doc":"```elixir\nalias MishkaInstaller.Event.Event\npurge_create([%Event{name: MyPlugin}], \"event_name\")\n```","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#purge_create/2-examples"},{"type":"function","title":"MishkaInstaller.Event.ModuleStateCompiler.rescue_initialize?/1","doc":"Safely checks if the event module is initialized, rescuing any errors.","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#rescue_initialize?/1"},{"type":"function","title":"Examples - MishkaInstaller.Event.ModuleStateCompiler.rescue_initialize?/1","doc":"```elixir\nrescue_initialize?(\"event_name\")\n```","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#rescue_initialize?/1-examples"},{"type":"function","title":"MishkaInstaller.Event.ModuleStateCompiler.safe_initialize?/1","doc":"Checks if the event module has an `initialize?` function exported.","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#safe_initialize?/1"},{"type":"function","title":"Examples - MishkaInstaller.Event.ModuleStateCompiler.safe_initialize?/1","doc":"```elixir\nsafe_initialize?(\"event_name\")\n```","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#safe_initialize?/1-examples"},{"type":"type","title":"MishkaInstaller.Event.ModuleStateCompiler.error_return/0","doc":"","ref":"MishkaInstaller.Event.ModuleStateCompiler.html#t:error_return/0"},{"type":"module","title":"MishkaInstaller.Installer.Downloader","doc":"The `MishkaInstaller.Installer.Downloader` module provides functions for downloading packages\nfrom various sources such as `Hex.pm` and `GitHub`.\n\nIt supports different download types and can fetch specific **versions** or the **latest releases**.\nThis module also includes functions for retrieving `mix.exs` files from these sources.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Downloader.html"},{"type":"function","title":"MishkaInstaller.Installer.Downloader.download/2","doc":"Downloads a package from the specified source.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Downloader.html#download/2"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Downloader.download/2","doc":"```elixir\ndownload(:hex, %{app: app, tag: tag_name})\ndownload(:github, %{path: path, branch: {branch, git: true}})\ndownload(:github, %{path: path, branch: branch})\ndownload(:github, %{path: path, release: release})\ndownload(:github, %{path: path, tag: tag})\ndownload(:hex, %{app: app})\ndownload(:github, %{path: path})\ndownload(:github_latest_release, %{path: path})\ndownload(:github_latest_tag, %{path: path})\n```","ref":"MishkaInstaller.Installer.Downloader.html#download/2-example"},{"type":"function","title":"MishkaInstaller.Installer.Downloader.get_mix/2","doc":"Retrieves the `mix.exs` file for the specified package.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Downloader.html#get_mix/2"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Downloader.get_mix/2","doc":"```elixir\nget_mix(:hex, %{app: app, tag: tag_name})\nget_mix(:github_release, %{path: path, release: tag_name})\nget_mix(:github_tag, %{path: path, tag: tag_name})\nget_mix(:hex, %{app: app})\nget_mix(:github, %{path: path})\nget_mix(:github_latest_release, %{path: path})\nget_mix(:github_latest_tag, %{path: path})\nget_mix(:url, %{path: path})\n```","ref":"MishkaInstaller.Installer.Downloader.html#get_mix/2-example"},{"type":"type","title":"MishkaInstaller.Installer.Downloader.download_type/0","doc":"","ref":"MishkaInstaller.Installer.Downloader.html#t:download_type/0"},{"type":"type","title":"MishkaInstaller.Installer.Downloader.error_return/0","doc":"","ref":"MishkaInstaller.Installer.Downloader.html#t:error_return/0"},{"type":"type","title":"MishkaInstaller.Installer.Downloader.okey_return/0","doc":"","ref":"MishkaInstaller.Installer.Downloader.html#t:okey_return/0"},{"type":"type","title":"MishkaInstaller.Installer.Downloader.pkg/0","doc":"","ref":"MishkaInstaller.Installer.Downloader.html#t:pkg/0"},{"type":"module","title":"MishkaInstaller.Installer.Installer","doc":"When it comes to `Erlan`g and `Elixir`, the process of runtime installing and runtime uninstalling a\nnew library or runtime upgrading it is subject to a number of constraints.\n\nThese restrictions can be implemented based on specific strategies and under specific conditions.\n\nPlease take note that this is not about **hot coding**, which refers to the process of updating\na module that was developed using `GenServer`.\n\nOn account of this objective, a number of action functions have been incorporated into\nthis module in order to make it possible for this task to be completed for you in\naccordance with some **established strategies**.\n\nAmong these tactics is the utilisation of the `Mix` tool, which is located within\nthe `System` and `Port` module.\n\n**During the subsequent releases, we will make an effort to incorporate the `script` mode**.\n- Based on: https://elixirforum.com/t/12114/14\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n\n> #### Use cases information {: .tip}\n>\n> Especially when you want to work with a library that depends on a large number\n> of other libraries or vice versa, each of the functions of this file has its own\n> requirements that must be taken into consideration.\n\n#### Note:\n> If you are using Phoenix as developer mode, please disable `live_reload` in `dev.exs`.\n> Please add `reloadable_apps: [:mishka_installer]` to your endpoint config in `config.exs` file.","ref":"MishkaInstaller.Installer.Installer.html"},{"type":"function","title":"MishkaInstaller.Installer.Installer.async_install/1","doc":"This function is the same as the `install/1` function, with the difference that it executes\none by one in a simple queue\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#async_install/1"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.async_install/1","doc":"```elixir\nalias MishkaInstaller.Installer.Installer\n\n# Normal calling\nInstaller.async_install(%__MODULE__{app: \"some_name\", path: \"some_name\", type: :hex})\n\n# Use builder\n{:ok, hex_tag} = Installer.builder(%{\n  app: \"mishka_developer_tools\",\n  version: \"0.1.5\",\n  tag: \"0.1.5\",\n  type: :hex,\n  path: \"mishka_developer_tools\"\n})\n\nInstaller.async_install(hex_tag)\n```","ref":"MishkaInstaller.Installer.Installer.html#async_install/1-example"},{"type":"function","title":"MishkaInstaller.Installer.Installer.builder/2","doc":"","ref":"MishkaInstaller.Installer.Installer.html#builder/2"},{"type":"function","title":"MishkaInstaller.Installer.Installer.delete/2","doc":"To delete a runtime library from Mnesia database by id or name.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#delete/2"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.delete/2","doc":"```elixir\ndelete(:app, \"mishka_developer_tools\")\n\ndelete(:id, \"c63aea42-209a-40fb-b5c6-a0d28ee7e25b\")\n```","ref":"MishkaInstaller.Installer.Installer.html#delete/2-example"},{"type":"function","title":"MishkaInstaller.Installer.Installer.drop/0","doc":"To drop all runtime libraries from Mnesia database.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#drop/0"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.drop/0","doc":"```elixir\ndrop()\n```","ref":"MishkaInstaller.Installer.Installer.html#drop/0-example"},{"type":"function","title":"MishkaInstaller.Installer.Installer.enforce_keys/0","doc":"","ref":"MishkaInstaller.Installer.Installer.html#enforce_keys/0"},{"type":"function","title":"MishkaInstaller.Installer.Installer.enforce_keys/1","doc":"","ref":"MishkaInstaller.Installer.Installer.html#enforce_keys/1"},{"type":"function","title":"MishkaInstaller.Installer.Installer.get/0","doc":"To get all runtime libraries information from Mnesia database.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#get/0"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.get/0","doc":"```elixir\nget()\n```","ref":"MishkaInstaller.Installer.Installer.html#get/0-example"},{"type":"function","title":"MishkaInstaller.Installer.Installer.get/1","doc":"To get a runtime library information from Mnesia database by id.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#get/1"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.get/1","doc":"```elixir\nget(\"c63aea42-209a-40fb-b5c6-a0d28ee7e25b\")\n```","ref":"MishkaInstaller.Installer.Installer.html#get/1-example"},{"type":"function","title":"MishkaInstaller.Installer.Installer.get/2","doc":"To get a runtime library information from Mnesia database by App name.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#get/2"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.get/2","doc":"```elixir\nget(:app, \"mishka_developer_tools\")\n```","ref":"MishkaInstaller.Installer.Installer.html#get/2-example"},{"type":"function","title":"MishkaInstaller.Installer.Installer.ids/0","doc":"To get all runtime libraries ids from Mnesia database.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#ids/0"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.ids/0","doc":"```elixir\nids()\n```","ref":"MishkaInstaller.Installer.Installer.html#ids/0-example"},{"type":"function","title":"MishkaInstaller.Installer.Installer.install/1","doc":"This function, in point of fact, combines a number of different methods for downloading,\ncompiling, and activating a library within the system. It is possible that this library\nis already present on the system, or it may serve as an update to the version that was\npreviously available.\n\nIt ought to be underlined. Adding or updating a library in the system\nis supported by three different techniques in this version of the software.\n\n1. Obtain the file from `hex.pm` and install it.\n2. Obtain the version from `GitHub` and install it.\n3. Install by utilising the `folder` itself direct.\n\n> Naturally, it is important to point out that there are also features that can\n> be used to enhance the system's customised functions. In order to accomplish this,\n> the programmer needs to incorporate additional functions into his/her programme,\n> such as downloading from a predetermined URL.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n\nIn reality, the structure of this module `__MODULE__.builder/1`, which likewise possesses\na high access level validation, is what this function takes as its input.\n\nIt is important to note that this validation and sanitizer is not intended for the user and\nis only necessary for the administrative level of data cleaning. **Pay particular attention\nto the cautions regarding security**.\n\n**For read more please see this type `MishkaInstaller.Installer.Installer.t()`**.","ref":"MishkaInstaller.Installer.Installer.html#install/1"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.install/1","doc":"```elixir\nalias MishkaInstaller.Installer.Installer\n\n# Normal calling\nInstaller.install(%__MODULE__{app: \"some_name\", path: \"some_name\", type: :hex})\n\n# Use builder\n{:ok, hex_tag} = Installer.builder(%{\n  app: \"mishka_developer_tools\",\n  version: \"0.1.5\",\n  tag: \"0.1.5\",\n  type: :hex,\n  path: \"mishka_developer_tools\"\n})\n\nInstaller.install(hex_tag)\n```\n\n#### More info:\n\n- `type` --> hex - github - github_latest_release - github_latest_tag - url - extracted\n- `compile_type` --> cmd - port - mix\n- Download methods see `MishkaInstaller.Installer.Downloader`","ref":"MishkaInstaller.Installer.Installer.html#install/1-example"},{"type":"function","title":"MishkaInstaller.Installer.Installer.keys/0","doc":"","ref":"MishkaInstaller.Installer.Installer.html#keys/0"},{"type":"function","title":"MishkaInstaller.Installer.Installer.keys/1","doc":"","ref":"MishkaInstaller.Installer.Installer.html#keys/1"},{"type":"function","title":"MishkaInstaller.Installer.Installer.uninstall/1","doc":"This function allows you to remove a library's directory from the build folder\nand deactivate the library from runtime.\n\n> Note that the sub-set libraries are not removed by this function.\n>\n> In later versions, a checker to delete **sub-ap**p libraries might be included.\n> You can add it as a custom for now.\n\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n\n```elixir\nalias MishkaInstaller.Installer.Installer\n\n# Normal calling\nInstaller.uninstall(%__MODULE__{app: \"some_name\", path: \"some_name\", type: :hex})\n```","ref":"MishkaInstaller.Installer.Installer.html#uninstall/1"},{"type":"function","title":"MishkaInstaller.Installer.Installer.uninstall/2","doc":"The only difference of this function is in the custom path of deleting the build directory.\nSee `uninstall/1`.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#uninstall/2"},{"type":"function","title":"MishkaInstaller.Installer.Installer.unique/2","doc":"To check is a runtime library unique or not in Mnesia database.\n\n> It returns `:ok`, or `{:error, reason}`. Note that if the requested runtime library does not exist,\n> It means it is unique, and if it is already in the database, it means it is not unique\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#unique/2"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.unique/2","doc":"```elixir\nunique(:app, \"mishka_developer_tools\")\n```","ref":"MishkaInstaller.Installer.Installer.html#unique/2-example"},{"type":"function","title":"MishkaInstaller.Installer.Installer.unique?/2","doc":"This function is exactly like `unique/2` function, except that its output is a Boolean.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#unique?/2"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.unique?/2","doc":"```elixir\nunique?(:app, \"mishka_developer_tools\")\n```","ref":"MishkaInstaller.Installer.Installer.html#unique?/2-example"},{"type":"function","title":"MishkaInstaller.Installer.Installer.write/1","doc":"To Add or edit a runtime library information from Mnesia database.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#write/1"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.write/1","doc":"```elixir\ndata = %{app: \"uniq\", version: \"0.6.1\", tag: \"0.6.1\", type: :hex, path: \"uniq\"}\nwrite(data)\n```","ref":"MishkaInstaller.Installer.Installer.html#write/1-example"},{"type":"function","title":"MishkaInstaller.Installer.Installer.write/3","doc":"To edit a specific field/fields of a runtime library from the Mnesia database.\n\n> The first input can only be name and ID `[:app]`.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.Installer.html#write/3"},{"type":"function","title":"Example: - MishkaInstaller.Installer.Installer.write/3","doc":"```elixir\nwrite(:app, \"mishka_developer_tools\", %{type: :hex})\n\nwrite(:id, \"c63aea42-209a-40fb-b5c6-a0d28ee7e25b\", %{type: :hex})\n```","ref":"MishkaInstaller.Installer.Installer.html#write/3-example"},{"type":"type","title":"MishkaInstaller.Installer.Installer.branch/0","doc":"","ref":"MishkaInstaller.Installer.Installer.html#t:branch/0"},{"type":"type","title":"MishkaInstaller.Installer.Installer.builder_entry/0","doc":"","ref":"MishkaInstaller.Installer.Installer.html#t:builder_entry/0"},{"type":"type","title":"MishkaInstaller.Installer.Installer.com_type/0","doc":"","ref":"MishkaInstaller.Installer.Installer.html#t:com_type/0"},{"type":"type","title":"MishkaInstaller.Installer.Installer.dep_type/0","doc":"","ref":"MishkaInstaller.Installer.Installer.html#t:dep_type/0"},{"type":"type","title":"MishkaInstaller.Installer.Installer.download_type/0","doc":"","ref":"MishkaInstaller.Installer.Installer.html#t:download_type/0"},{"type":"type","title":"MishkaInstaller.Installer.Installer.error_return/0","doc":"","ref":"MishkaInstaller.Installer.Installer.html#t:error_return/0"},{"type":"type","title":"MishkaInstaller.Installer.Installer.okey_return/0","doc":"","ref":"MishkaInstaller.Installer.Installer.html#t:okey_return/0"},{"type":"type","title":"MishkaInstaller.Installer.Installer.t/0","doc":"","ref":"MishkaInstaller.Installer.Installer.html#t:t/0"},{"type":"module","title":"MishkaInstaller.Installer.LibraryHandler","doc":"This module provides programmers with a public APIs and helpers that allow them to\nconstruct their own custom functions.\n\n> It also includes aids and tools that allow them to work with the library while it is running.\n\n`MishkaInstaller.Installer.Installer` is also referred to as action and aggregator functions,\nwhich is something that should be taken into consideration.\n\nIf you are unsure about the responsibilities of each function,\nit is recommended that you utilise the `MishkaInstaller.Installer.Installer` module and its functions,\nwhich consist of a collection of predefined strategies.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n\n> #### Use cases information {: .tip}\n>\n> Especially when you want to work with a library that depends on a large number\n> of other libraries or vice versa, each of the functions of this file has its own\n> requirements that must be taken into consideration.","ref":"MishkaInstaller.Installer.LibraryHandler.html"},{"type":"function","title":"MishkaInstaller.Installer.LibraryHandler.application_ensure/1","doc":"Helper function to load an application and all its dependencies.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.LibraryHandler.html#application_ensure/1"},{"type":"function","title":"Example: - MishkaInstaller.Installer.LibraryHandler.application_ensure/1","doc":"```elixir\napplication_ensure(:mishka_developer_tools)\n```","ref":"MishkaInstaller.Installer.LibraryHandler.html#application_ensure/1-example"},{"type":"function","title":"MishkaInstaller.Installer.LibraryHandler.command_execution/3","doc":"Helper function that executes system and script commands.\n\n\n#### Ref:\n\n* https://hexdocs.pm/elixir/Port.html#module-spawn_executable\n* https://elixirforum.com/t/48336/\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.LibraryHandler.html#command_execution/3"},{"type":"function","title":"Example: - MishkaInstaller.Installer.LibraryHandler.command_execution/3","doc":"```elixir\ncommand_execution(:cmd, \"deps.get\")\n\ncommand_execution(:port, \"deps.get\")\n```","ref":"MishkaInstaller.Installer.LibraryHandler.html#command_execution/3-example"},{"type":"function","title":"MishkaInstaller.Installer.LibraryHandler.do_compile/1","doc":"This particular function executes the necessary instructions in order to download the\ndependencies, compile the dependencies, and compile the project itself.\n\n- In the present version, there are two options that are available, namely `Port` and `System`.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.\n\n```elixir\nalias MishkaInstaller.Installer.{Installer, LibraryHandler}\n\ndo_compile(%Installer{app: \"some_name\", path: \"some_name\", type: :hex})\n```\n\n**During the subsequent releases, we will make an effort to incorporate the `script` mode**.\n- Based on: https://elixirforum.com/t/12114/14","ref":"MishkaInstaller.Installer.LibraryHandler.html#do_compile/1"},{"type":"function","title":"MishkaInstaller.Installer.LibraryHandler.extensions_path/0","doc":"Helper function to get download path and extract runtime libraries.","ref":"MishkaInstaller.Installer.LibraryHandler.html#extensions_path/0"},{"type":"function","title":"Example: - MishkaInstaller.Installer.LibraryHandler.extensions_path/0","doc":"```elixir\nextensions_path()\n```","ref":"MishkaInstaller.Installer.LibraryHandler.html#extensions_path/0-example"},{"type":"function","title":"MishkaInstaller.Installer.LibraryHandler.extract/3","doc":"A helper function to extract downloaded libraries from `hex.pm`, `github` and custom `url`.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.LibraryHandler.html#extract/3"},{"type":"function","title":"Example: - MishkaInstaller.Installer.LibraryHandler.extract/3","doc":"```elixir\nextract(:tar, a_path, \"app_name-version\")\n```","ref":"MishkaInstaller.Installer.LibraryHandler.html#extract/3-example"},{"type":"function","title":"MishkaInstaller.Installer.LibraryHandler.move/2","doc":"Helper function to transfer files to the deployment path.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.LibraryHandler.html#move/2"},{"type":"function","title":"Example: - MishkaInstaller.Installer.LibraryHandler.move/2","doc":"```elixir\nmove(app, \"archived_file_binary\")\n```","ref":"MishkaInstaller.Installer.LibraryHandler.html#move/2-example"},{"type":"function","title":"MishkaInstaller.Installer.LibraryHandler.move_and_replace_build_files/1","doc":"Helper function to transfer and replace built libs to the project `_build` dir.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.LibraryHandler.html#move_and_replace_build_files/1"},{"type":"function","title":"Example: - MishkaInstaller.Installer.LibraryHandler.move_and_replace_build_files/1","doc":"```elixir\nalias MishkaInstaller.Installer.{Installer, LibraryHandler}\n\nmove_and_replace_build_files(%Installer{app: \"some_name\", path: \"some_name\", type: :hex})\n```","ref":"MishkaInstaller.Installer.LibraryHandler.html#move_and_replace_build_files/1-example"},{"type":"function","title":"MishkaInstaller.Installer.LibraryHandler.prepend_compiled_apps/1","doc":"By means of this helper function, identify the paths of dependencies to the Erlang VM.\n\nFor more information see `Code.prepend_path/1`.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.LibraryHandler.html#prepend_compiled_apps/1"},{"type":"function","title":"Example: - MishkaInstaller.Installer.LibraryHandler.prepend_compiled_apps/1","doc":"```elixir\nfiles_list = [\n  decimal: \"/_build/dev/lib/decimal/ebin\",\n  ecto: \"/_build/dev/lib/ecto/ebin\",\n  uniq: \"/_build/dev/lib/uniq/ebin\"\n]\n\nprepend_compiled_apps(files_list)\n```","ref":"MishkaInstaller.Installer.LibraryHandler.html#prepend_compiled_apps/1-example"},{"type":"function","title":"MishkaInstaller.Installer.LibraryHandler.read_app/2","doc":"Helper function to read Erlang `.app` file in Elixir.\n\nReads the given app from path in an optimized format and returns its contents.\n\nBased on:\nhttps://github.com/elixir-lang/elixir/blob/f0fcd64f937af8ccdd98e086c107c3902485d404/lib/mix/lib/mix/app_loader.ex#L59-L75\n\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.LibraryHandler.html#read_app/2"},{"type":"function","title":"Example: - MishkaInstaller.Installer.LibraryHandler.read_app/2","doc":"```elixir\nread_app(:mishka_developer_tools, app_bin_path)\n```","ref":"MishkaInstaller.Installer.LibraryHandler.html#read_app/2-example"},{"type":"function","title":"MishkaInstaller.Installer.LibraryHandler.unload/1","doc":"Helper function to unload an application.\n\n> #### Security considerations {: .warning}\n>\n> It is important to remember that all of the functionalities contained within this\n> section must be implemented at the **high access level**, and they should not directly take\n> any input from the user. Ensure that you include the required safety measures.","ref":"MishkaInstaller.Installer.LibraryHandler.html#unload/1"},{"type":"function","title":"Example: - MishkaInstaller.Installer.LibraryHandler.unload/1","doc":"```elixir\nunload(:mishka_developer_tools)\n```","ref":"MishkaInstaller.Installer.LibraryHandler.html#unload/1-example"},{"type":"type","title":"MishkaInstaller.Installer.LibraryHandler.app/0","doc":"","ref":"MishkaInstaller.Installer.LibraryHandler.html#t:app/0"},{"type":"type","title":"MishkaInstaller.Installer.LibraryHandler.compile_time_type/0","doc":"","ref":"MishkaInstaller.Installer.LibraryHandler.html#t:compile_time_type/0"},{"type":"type","title":"MishkaInstaller.Installer.LibraryHandler.error_return/0","doc":"","ref":"MishkaInstaller.Installer.LibraryHandler.html#t:error_return/0"},{"type":"type","title":"MishkaInstaller.Installer.LibraryHandler.io_device/0","doc":"","ref":"MishkaInstaller.Installer.LibraryHandler.html#t:io_device/0"},{"type":"type","title":"MishkaInstaller.Installer.LibraryHandler.okey_return/0","doc":"","ref":"MishkaInstaller.Installer.LibraryHandler.html#t:okey_return/0"},{"type":"type","title":"MishkaInstaller.Installer.LibraryHandler.posix/0","doc":"","ref":"MishkaInstaller.Installer.LibraryHandler.html#t:posix/0"},{"type":"type","title":"MishkaInstaller.Installer.LibraryHandler.runtime_type/0","doc":"","ref":"MishkaInstaller.Installer.LibraryHandler.html#t:runtime_type/0"},{"type":"module","title":"MishkaInstaller.MnesiaRepo.State","doc":"","ref":"MishkaInstaller.MnesiaRepo.State.html"},{"type":"extras","title":"Mishka Installer is a system plugin(event) manager and run time installer for Elixir.","doc":"# Mishka Installer is a system plugin(event) manager and run time installer for Elixir.\n\n[![MishkaInstaller CI](https://github.com/mishka-group/mishka_installer/actions/workflows/ci.yml/badge.svg)](https://github.com/mishka-group/mishka_installer/actions/workflows/ci.yml) [![Hex.pm](https://img.shields.io/badge/hex-0.1.0-blue.svg)](https://hex.pm/packages/mishka_installer) [![GitHub license](https://img.shields.io/badge/apache-2.0-green.svg)](https://raw.githubusercontent.com/mishka-group/mishka_installer/master/LICENSE) ![GitHub issues](https://img.shields.io/github/issues/mishka-group/mishka_installer)","ref":"readme.html"},{"type":"extras","title":"Build purpose - Mishka Installer is a system plugin(event) manager and run time installer for Elixir.","doc":"---\n\nImagine you are going to make an application that will have many plugins built for it in the future.\nBut the fact that many manipulations will be made on your source code makes it difficult to\nmaintain the application. For example, you present a content management system for your users,\nand now they need to activate a section for registration and `SMS`; the system allows you to\npresent your desired input/output absolutely plugin oriented to your users and makes it\npossible for the developers to write their required applications beyond the core source code.\n\n\n> **NOTICE**: Do not use the master branch; this library is under heavy development.\n> Expect version 0.1.0, and for using the new features, please wait until a new release is out.\n\n\n##### This library is divided into the following main sections:\n\n- [Events and Hook](#events-and-hook)\n- [Plugin management system theory and installation of Elixir libraries at runtime](#plugin-management-system-theory-and-installation-of-elixir-libraries-at-runtime)","ref":"readme.html#build-purpose"},{"type":"extras","title":"Events and Hook - Mishka Installer is a system plugin(event) manager and run time installer for Elixir.","doc":"---\n\nIn this section, you can define a series of events for each event,\nfor example: after **successful registration** or **unsuccessful purchase** from “the store”,\nand for each event, put a set of callbacks in one module.\n\nAfter completing this step, when the user wants to create his own plugin,\nthe Macro `behaviour` and `Hook` module will call you in its action module.\n\nThis helps you have a regular and `error-free` system, and the library uses an almost\nintegrated structure in all of its events.\n\n> In **Mishka Installer** Library, a series of action or hook functions are\ngiven to the developer of the main plugin or software, which helps build plugins **outside**/**inside**\nthe system and convert software sections into separate events.\n\n**Some of the functions of this module include the following:**\n\n- Retrieves the merged configuration for the hook module.\n- Register a plugin for a specific event.\n- Start a plugin of a specific event.\n- Restart a plugin of a specific event.\n- Stop a plugin of a specific event.\n- Unregister a plugin of a specific event.\n- Retrieves a Plugin `GenServer` state.\n- Each plugin has A `GenServer` to do some auto jobs.\n\n> For more information please see the `MishkaInstaller.Event.Hook` module.\n\n##### Example:\n\n```elixir\ndefmodule RegisterEmailSender do\n  use MishkaInstaller.Event.Hook, event: \"after_success_login\"\n\n  def call(entries) do\n    {:reply, entries}\n  end\nend\n```\n\n**If you want to change a series of default information, do this:**\n\n```elixir\nuse MishkaInstaller.Event.Hook,\n  event: \"after_success_login\",\n  initial: %{depends: [SomeEvent], priority: 20}\n```\n\n**You can call all plugins of an event:**\n\n```elixir\nalias MishkaInstaller.Event.Hook\n\n# Normal call an event plugins\nHook.call(\"after_success_login\", params)\n\n# If you want certain entries not to change\nHook.call(\"after_success_login\", params, [private: something_based_on_your_data])\n\n# If you want the initial entry to be displayed at the end\nHook.call(\"after_success_login\", params, [return: true])\n```\n\n**Note: If you want your plugin to execute automatically,\nall you need to do is send the name of the module in which you utilized\nthe `MishkaInstaller.Event.Hook` to the Application module.***\n\n```elixir\nchildren = [\n  ...\n  RegisterEmailSender\n]\n\n...\nopts = [strategy: :one_for_one, name: SomeModule.Supervisor]\nSupervisor.start_link(children, opts)\n```\n\n> This module is a read-only in-memory storage optimized for the fastest possible read times\n> not for write strategies.","ref":"readme.html#events-and-hook"},{"type":"extras","title":"Plugin management system theory and installation of Elixir libraries at runtime - Mishka Installer is a system plugin(event) manager and run time installer for Elixir.","doc":"---\n\nThe functionality of this library can be conceptualized as an architectural potential that is\ncomposed of two primary components, which are as follows:\n\n1. Event management (Plugin Hook powered by **Elixir Macro**)\n2. Managing removal and installation of Elixir libraries at `runtime`.\n\nWhen a programmer uses this library for his own software development, we sought to\nensure that in addition to the established capabilities, he also has access to a set of\nappropriate standards for software development that are based on preset behaviors that can be applied;\nThis was our goal.\n\nIt streamlines and organizes the work of a group working on a project while also facilitating\nthe creation of software.\nError control and tree structure, which enable us to develop a system that is robust and trustworthy,\nare two of the guiding ideas behind the construction of this library, which has garnered\nattention from people all around the world.\n\nThe [MishkaInstaller](https://github.com/mishka-group/mishka_installer) library can be created in\nvarious systems, and it provides fundamental capabilities such as the management of plugin states\nand the application of standard behaviors.\nThese features can all be accessed by specified hooks in the library.\n\n> **The installer part is in beta mode, use it carefully and some of its functionality may not work in the Elixir `release`.**\n\n##### Example:\n\n```elixir\nalias MishkaInstaller.Installer.Installer\n\n# Normal calling\nInstaller.install(%__MODULE__{app: \"some_name\", path: \"some_name\", type: :hex})\n\n# Normal calling\nInstaller.uninstall(%__MODULE__{app: \"some_name\", path: \"some_name\", type: :hex})\n\n# Normal calling\nInstaller.async_install(%__MODULE__{app: \"some_name\", path: \"some_name\", type: :hex})\n```\n\n> For more information please see the `MishkaInstaller.Installer.Installer` module.","ref":"readme.html#plugin-management-system-theory-and-installation-of-elixir-libraries-at-runtime"},{"type":"extras","title":"Installing the library: - Mishka Installer is a system plugin(event) manager and run time installer for Elixir.","doc":"---\n\nIt should be noted that this library must be installed in two parts of the plugin and the\nsoftware that wants to display the plugins, and due to its small dependencies, it does\nnot cause any problems. To install, just add this library to your \"mix.exs\" in the \"deps\"\nfunction as follows:\n\n```elixir\ndef deps do\n  [\n    {:mishka_installer, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThe docs can be found at https://hexdocs.pm/mishka_installer.\n\n---\n\n# Donate\n\nIf the project was useful for you, the only way you can donate to me is the following ways\n\n| **BTC**                                                                                                                            | **ETH**                                                                                                                            | **DOGE**                                                                                                                           | **TRX**                                                                                                                            |\n| ---------------------------------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------- |\n|   |   |   |   |\n\n \n   Donate addresses \n\n**BTC**:‌\n\n```\nbc1q24pmrpn8v9dddgpg3vw9nld6hl9n5dkw5zkf2c\n```\n\n**ETH**:\n\n```\n0xD99feB9db83245dE8B9D23052aa8e62feedE764D\n```\n\n**DOGE**:\n\n```\nDGGT5PfoQsbz3H77sdJ1msfqzfV63Q3nyH\n```\n\n**TRX**:\n\n```\nTBamHas3wAxSEvtBcWKuT3zphckZo88puz\n```","ref":"readme.html#installing-the-library"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}